using System;

namespace FlickeringListview
{
    public delegate void UpdatedEventHandler(object sender, DataUpdatedEventArgs e);

    public class DataUpdatedEventArgs : EventArgs
    {
        private int myUpdatedIndex;
        private double myPreviousValue, myNewValue;

        public DataUpdatedEventArgs(int updatedIndex, double previousValue, double newValue)
        {
            this.myUpdatedIndex = updatedIndex;
            this.myPreviousValue = previousValue;
            this.myNewValue = newValue;
        }

        public int updatedIndex
        {
            get { return myUpdatedIndex; }
        }

        public double previousValue
        {
            get { return myPreviousValue; }
        }

        public double newValue
        {
            get { return myNewValue; }
        }
    }

	/// <summary>
	/// Summary description for Datum.
	/// </summary>
	public class Datum
	{
        double[] myData;

		public Datum(int numPoints)
		{
            myData = new double[numPoints];
		}

        public void update(int index, double newValue)
        {
            fireUpdatedEvent(index, myData[index], newValue);
            myData[index] = newValue;
        }

        protected void fireUpdatedEvent(int index, double previousValue, double newValue)
        {
            DataUpdatedEventArgs e = new DataUpdatedEventArgs(index, previousValue, newValue);
            onUpdated(e);
        }

        public double this[int index]
        {
            get { return myData[index]; }
        }

        public int Length
        {
            get { return myData.Length; }
        }

        public event UpdatedEventHandler updated;
        private delegate void onUpdatedDelegate(DataUpdatedEventArgs e);
        protected virtual void onUpdated(DataUpdatedEventArgs e)
        {
            if (updated != null)
                updated(this, e);
        }

	}
}
